/*
 * File: brokerinfo.h
 * Author: Monforte Salvatore
 * For license conditions see http://www.eu-datagrid.org/license.html
 */

// $Id: brokerinfo.h,v 1.1.30.2.2.3 2009/07/29 08:15:58 monforte Exp $

#ifndef _GLITE_WMS_BROKERINFO_BROKERINFO_H_
#define _GLITE_WMS_BROKERINFO_BROKERINFO_H_

#include <boost/tuple/tuple.hpp>
#include <boost/shared_ptr.hpp>

#include <map>
#include <string>
#include <set>
#include <vector>
#include <utility>

namespace classad
{
  class ClassAd;
}

namespace glite {
namespace wms {
namespace brokerinfo {


typedef
std::map<
  std::string,             // lfn
  std::vector<std::string> // sfns
> FileMapping;

struct StorageInfo
{
  typedef std::set<std::pair<std::string, int> > Protocols;
  typedef std::vector<FileMapping::const_iterator> Links;
  typedef std::vector<std::pair<std::string, std::string> > CE_Mounts;

  Protocols protocols;
  Links links;
  CE_Mounts ce_mounts;
};

typedef std::map<std::string, StorageInfo> StorageMapping;

struct DataInfo
{
  boost::shared_ptr<FileMapping> fm;
  boost::shared_ptr<StorageMapping> sm;
  DataInfo(
    boost::shared_ptr<FileMapping> f,
    boost::shared_ptr<StorageMapping> s
  ) : fm(f), sm(s) {}
};

classad::ClassAd*
create_brokerinfo(
  classad::ClassAd const& jdl_ad,
  classad::ClassAd const& ce_ad,
  DataInfo const& data_info
);

}; // namespace brokerinfo
}; // namespace wms
}; // namespace glite

#endif
